@@ -6,11 +6,13 @@ Refer `code-stats-vim
 `_.
 """
 
+import asyncio
 import json
 import logging
 from dataclasses import dataclass
 from datetime import datetime
 from socket import gethostname
+from threading import Event, Lock, Thread
 from time import time
 
 from aiohttp import ClientSession
@@ -30,7 +32,7 @@ class CodeStats(Hook):
 
     service_name: str = "codestats"
     user_name: str = gethostname()
-    url: str = "https://codestats.net/api/my/pulses"
+    url: str = "https://codestats.net/api/my/pulses/"
     interval: int = 60  # interval at which stats are sent
     timeout: ClientTimeout | None = None
 
@@ -58,10 +60,15 @@ class CodeStats(Hook):
         }
         self.datetime = datetime.now().astimezone()
         if self.timeout is None:
-            self.timeout = ClientTimeout(1)
+            self.timeout = ClientTimeout(10)
         self.session = None
+        self.loop = asyncio.new_event_loop()
+        self.thread = Thread(target=self.worker, daemon=True)
+        self.thread.start()
+        self.event = Event()
+        self.lock = Lock()
 
-    async def __call__(self, xp: int = 1) -> None:
+    def __call__(self, xp: int = 1) -> None:
         """Add xp.
 
         Sem sections are super small so this should be quick if it blocks.
@@ -70,38 +77,53 @@ class CodeStats(Hook):
         :type xp: int
         :rtype: None
         """
-        self.data["xps"][0]["xp"] += xp
+        with self.lock:
+            self.data["xps"][0]["xp"] += xp
         if time() - self.datetime.timestamp() > self.interval:
-            await self.send_xp()
+            self.event.set()
 
-    async def __del__(self) -> None:
-        await self.send_xp()
+    def worker(self) -> None:
+        """Worker.
+
+        :param self:
+        :rtype: None
+        """
+        asyncio.set_event_loop(self.loop)
+        while True:
+            self.event.wait()
+            self.loop.run_until_complete(self.send_xp())
+            self.event.clear()
+
+    def __del__(self) -> None:
+        if self.session:
+            self.loop.run_until_complete(self.session.close())
+        self.loop.close()
 
     async def send_xp(self) -> str:
         """Send xp.
 
         :rtype: str
         """
-        if self.data["xps"][0]["xp"] == 0:
-            return ""
-
-        self.datetime = datetime.now().astimezone()
-        self.data["coded_at"] = self.datetime.isoformat()
-        data = json.dumps(self.data).encode("utf-8")
-        text = ""
         if self.session is None:
             self.session = ClientSession(
                 base_url=self.url,
                 headers=self.headers,
                 timeout=self.timeout,
             )
+        self.datetime = datetime.now().astimezone()
+        self.data["coded_at"] = self.datetime.isoformat()
+        text = ""
+        with self.lock:
+            data = json.dumps(self.data).encode("utf-8")
+            xp = self.data["xps"][0]["xp"]
         try:
             async with self.session.post(
                 "/",
                 data=data,
             ) as resp:
                 text = await resp.text()
-            self.data["xps"][0]["xp"] = 0
+            with self.lock:
+                self.data["xps"][0]["xp"] -= xp
         except TimeoutError as error:
             logger.error(error)
         return text
